function y = SweepLigandModel()
close all

%parameter values

RM_conc = 0;
RD_conc = 1000;
LM_conc = 0;
LD_concs = logspace(-2,6,40);

kon = 5e-4; %m2/sec
koff = 1*10; %sec-1
sigmas = [0, 1, 10, 100, 1000, 10000, 100000, 1000000]; %local concentration
kon2 = kon*sigmas; %m2/sec
koff2 = koff; %sec-1
kp1 = 0.1; %sec-1
kp2 = 1e8; %sec-1
kthres = 2; 

parameters = [kon, koff, kon2, koff2, kp1, kp2];

%solving the model

steadystates = zeros(length(LD_concs), length(sigmas), 11);
op1=optimset;op1.TolX=1e-5;op1.TolFun=1e-5;
for j = 1:length(sigmas)
    sigma_j = sigmas(j); 
    kon2 = kon*sigma_j;
    parameters = [kon, koff, kon2, koff2, kp1, kp2];
    for i = 1:length(LD_concs)

        starting_concs = zeros(1, 74);
        starting_concs(1) = RM_conc;
        starting_concs(2) = RD_conc;
        starting_concs(3) = LM_conc;
        starting_concs(4) = LD_concs(i);

        [t, y] = ode23s(@(time, species)SolveLigandModel(time, species, parameters), [0 1e6], starting_concs,op1);
        size(y);
        steadystates(i,j,:) = calc_observables(y(end,:));

    end
end

RMbound_steadystates = steadystates(:,:,5);
RDboundb1_steadystates = steadystates(:,:,6);
RDboundb2_steadystates = steadystates(:,:,7);
RDbound_steadystates = steadystates(:,:,8);
Rtotal_steadystates = steadystates(:,:,9);
P_RM_steadystates = steadystates(:,:,10);
P_RD_steadystates = steadystates(:,:,11);

response = P_RD_steadystates ./ (kthres + P_RD_steadystates);

for m = 1:length(sigmas)
 normalized(:,m) = (P_RD_steadystates(:,m) - min(P_RD_steadystates(:,m))) ./ (max(P_RD_steadystates(:,m) - min(P_RD_steadystates(:,m))));
end 

%visualising the results

figure; hold on
for j = 1:length(sigmas)  
    plot(LD_concs, Rtotal_steadystates(:,j), 'o-')
end
legend('\sigma = 0', '\sigma = 1', '\sigma = 10', '\sigma = 100', '\sigma = 1000', '\sigma = 10000', '\sigma = 100000', '\sigma = 1000000');
xlabel('LD conc (AU)')
ylabel('Receptor bound total (AU)')
set(gca, 'Xscale', 'log')

figure; hold on
for j = 1:length(sigmas)  
    plot(LD_concs, P_RD_steadystates(:,j), 'o-')
end
legend('\sigma = 0', '\sigma = 1', '\sigma = 10', '\sigma = 100', '\sigma = 1000', '\sigma = 10000', '\sigma = 100000', '\sigma = 1000000');
xlabel('LD conc (AU)')
ylabel('Receptor phosphorylated (AU)')
set(gca, 'Xscale', 'log')

figure; hold on
for j = 1:length(sigmas)  
    plot(LD_concs, response(:,j), 'o-')
end
legend('\sigma = 0', '\sigma = 1', '\sigma = 10', '\sigma = 100', '\sigma = 1000', '\sigma = 10000', '\sigma = 100000', '\sigma = 1000000');
xlabel('LD conc (AU)')
ylabel('Response (AU)')
set(gca, 'Xscale', 'log')

figure; hold on
for j = 1:length(sigmas)  
   plot(LD_concs, normalized(:,j), 'o-')
end
legend('\sigma = 0', '\sigma = 1', '\sigma = 10', '\sigma = 100', '\sigma = 1000', '\sigma = 10000', '\sigma = 100000', '\sigma = 1000000');
xlabel('LD conc (AU)')
ylabel('Receptor phosphorylated (AU)')
set(gca, 'Xscale', 'log')


